@@ -13,6 +13,7 @@
 
 """ This module contains functions to analyse connectivity.
 """
+import math
 
 from itertools import combinations
 
@@ -242,8 +243,6 @@ def filter_connectivity(x, restrict_to, remote_instance=None):
 def cable_overlap(a, b, dist=2, method='min'):
     """Calculate the amount of cable of neuron A within distance of neuron B.
 
-    Uses dotproduct representation of a neuron!
-
     Parameters
     ----------
     a,b :       CatmaidNeuron | CatmaidNeuronList
@@ -291,6 +290,28 @@ def cable_overlap(a, b, dist=2, method='min'):
     matrix = pd.DataFrame(np.zeros((a.shape[0], b.shape[0])),
                           index=a.skeleton_id, columns=b.skeleton_id)
 
+    # Generate simple dotprops for each neuron
+    for nl in [a, b]:
+        for x in nl:
+            # Node locs
+            tn_locs = x.nodes[x.nodes.parent_id >= 0][['x', 'y', 'z']].values
+            # Parent locs
+            pn_locs = x.nodes.set_index('node_id', inplace=False).loc[x.nodes[x.nodes.parent_id >= 0].parent_id][['x', 'y', 'z']].values
+
+            # Get centers between each pair of locs
+            centers = tn_locs + (pn_locs - tn_locs) / 2
+
+            # Get vector between points
+            vec = pn_locs - tn_locs
+
+            dps = pd.DataFrame([[c, v] for c, v in zip(centers, vec)],
+                               columns=['point', 'vector'])
+
+            # Add length of vector (for convenience)
+            dps['vec_length'] = (dps.vector ** 2).apply(sum).apply(math.sqrt)
+
+            x._dps = dps
+
     with config.tqdm(total=len(a), desc='Calc. overlap',
                      disable=config.pbar_hide,
                      leave=config.pbar_leave) as pbar:
@@ -301,30 +322,30 @@ def cable_overlap(a, b, dist=2, method='min'):
             tA = trees.get(nA.skeleton_id, None)
             if not tA:
                 trees[nA.skeleton_id] = tA = scipy.spatial.cKDTree(
-                    np.vstack(nA.dps.point), leafsize=10)
+                    np.vstack(nA._dps.point), leafsize=10)
 
             for nB in b:
                 # Get cKDTree for nB
                 tB = trees.get(nB.skeleton_id, None)
                 if not tB:
                     trees[nB.skeleton_id] = tB = scipy.spatial.cKDTree(
-                        np.vstack(nB.dps.point), leafsize=10)
+                        np.vstack(nB._dps.point), leafsize=10)
 
                 # Query nB -> nA
-                distA, ixA = tA.query(np.vstack(nB.dps.point),
+                distA, ixA = tA.query(np.vstack(nB._dps.point),
                                       k=1,
                                       distance_upper_bound=dist,
-                                      n_jobs=-1
+                                      workers=-1
                                       )
                 # Query nA -> nB
-                distB, ixB = tB.query(np.vstack(nA.dps.point),
+                distB, ixB = tB.query(np.vstack(nA._dps.point),
                                       k=1,
                                       distance_upper_bound=dist,
-                                      n_jobs=-1
+                                      workers=-1
                                       )
 
-                nA_in_dist = nA.dps.loc[ixA[distA != float('inf')]]
-                nB_in_dist = nB.dps.loc[ixB[distB != float('inf')]]
+                nA_in_dist = nA._dps.loc[ixA[distA != float('inf')]]
+                nB_in_dist = nB._dps.loc[ixB[distB != float('inf')]]
 
                 if nA_in_dist.empty:
                     overlap = 0
@@ -472,7 +493,7 @@ def predict_connectivity(source, target, method='possible_contacts',
                 dist, ix = tree.query(s.presynapses[['x', 'y', 'z']].values,
                                       k=1,
                                       distance_upper_bound=dist_threshold,
-                                      n_jobs=-1
+                                      workers=-1
                                       )
 
                 # Calculate possible contacts
